Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type UiBuilderConfig ¶
type UiBuilderConfig struct {
Module string `json:"module" yaml:"module"`
Version string `json:"version" yaml:"version"`
Dependencies []string `json:"dependencies" yaml:"dependencies"`
DependencyDir string `json:"dependency_dir" yaml:"dependency_dir"`
U33eFormat string `json:"u33e_format" yaml:"u33e_format"`
InstalledSpecDir string `json:"installed_spec_dir" yaml:"installed_spec_dir"`
UiSpecsOutputDir string `json:"ui_specs_output_dir" yaml:"ui_specs_output_dir"`
Commands map[string]string `json:"commands" yaml:"commands"`
Flows map[string][]string `json:"flow" yaml:"flows"`
Hooks map[string][]string `json:"hooks" yaml:"hooks"`
Build map[string]string `json:"build" yaml:"build"`
}
module: "github.com/sample/repo" #the name of the git repo where your spec project resides version: "v0.0.1" dependencies: - "git@git.devres.internal.adcubum.com:7999/syrsl/syrius-claimsmgmt-servicesmgmt-bff-spec.git master" - "github.com/theNorstroem/furoBaseTypes v1.0.0" # The importer looks for all **/*.type.spec files recursive The importer looks for all **/*.service.spec files recursive dependenciesDir: installedSpecs u33eFormat: "yaml" #set to yaml or json installedSpecDir: "./specs" uiSpecsOutputDir: "./ui_specs/" commands: dummyCmd: "scripts/dummy.sh" flows:
default:
initUiSpecs
hooks: types:
"./node_modules/@furo/ui-builder/_scripts/hook-initializer-form-ui5.js" services:
"./node_modules/@furo/ui-builder/_scripts/hook-initializer-reference-search-ui5.js" build: components: targetDir: "./dist/components/generated_components"
Click to show internal directories.
Click to hide internal directories.